# h3ppy
A python package for modelling and fitting H<sub>3</sub><sup>+</sup> spectra

## Install via pip
```
pip3 install h3ppy
```

Full [documentation on Github](https://github.com/henrikmelin/h3ppy).
